resource "aws_security_group" "docker" {
  name        = "docker-group"
  description = "Default security group that allows Docker daemon to be called remotely."
  vpc_id      = var.aws_vpc.id

  tags = {
    Name = "${var.env}-docker-sg"
    Env  = var.env
  }

  # Docker daemon
  ingress {
    from_port   = 2375
    to_port     = 2376
    protocol    = "tcp"
    cidr_blocks = flatten([var.swarm_mgmt_cidrs, module.terraform_host.cidr])
  }
}

resource "aws_security_group" "ssh" {
  name        = "ssh-group"
  description = "Default security group that allows SSH to the infrastructure."
  vpc_id      = var.aws_vpc.id

  tags = {
    Name = "${var.env}-ssh-sg"
    Env  = var.env
  }

  # SSH
  ingress {
    from_port   = 22
    to_port     = 22
    protocol    = "tcp"
    cidr_blocks = [
      var.env == "dev" ? "0.0.0.0/0" : module.terraform_host.cidr,
    ]
  }
}

resource "aws_security_group" "vpc" {
  name        = "vpc-group"
  description = "Default security group that allows all inbound and outbound traffic in the VPC."
  vpc_id      = var.aws_vpc.id

  tags = {
    Name = "${var.env}-vpc-sg"
    Env  = var.env
  }

  # Allow all outgoing
  egress {
    from_port   = "0"
    to_port     = "0"
    protocol    = "-1"
    cidr_blocks = [
      "0.0.0.0/0",
    ]
  }
  # Enable ICMP (echo)
  ingress {
    from_port   = -1
    to_port     = -1
    protocol    = "icmp"
    cidr_blocks = [
      "0.0.0.0/0",
    ]
  }
  # Allow all TCP communication inside private VPC network
  ingress {
    from_port   = 0
    to_port     = 65535
    protocol    = "tcp"
    cidr_blocks = [
      var.aws_vpc.cidr_block,
    ]
  }
  # Allow all UDP communication inside private VPC network
  ingress {
    from_port   = 0
    to_port     = 65535
    protocol    = "udp"
    cidr_blocks = [
      var.aws_vpc.cidr_block,
    ]
  }
  # Docker Swarm mesh routing needs: tcp/2377, tcp_upd/7946, udp/4789 - inside VPC
}
