resource "aws_vpc" "default" {
  cidr_block = var.cidr

  enable_dns_support   = true
  enable_dns_hostnames = var.enable_dns_hostnames

  tags = {
    Name = var.env
    Env  = var.env
  }

  lifecycle {
    #prevent_destroy = true
    ignore_changes = [
      tags,
    ]
  }
}

resource "aws_main_route_table_association" "rtb_assoc" {
  vpc_id         = aws_vpc.default.id
  route_table_id = aws_route_table.rtb.id
}

resource "aws_internet_gateway" "ig" {
  vpc_id = aws_vpc.default.id

  tags = {
    Name = var.env
    Env  = var.env
  }

  lifecycle {
    ignore_changes = [
      tags,
    ]
  }
}

resource "aws_route_table" "rtb" {
  vpc_id = aws_vpc.default.id

  route {
    cidr_block = "0.0.0.0/0"
    gateway_id = aws_internet_gateway.ig.id
  }

  tags = {
    Name = var.env
    Env  = var.env
  }

  lifecycle {
    ignore_changes = [
      tags,
    ]
  }
}

resource "aws_subnet" "default" {
  count                   = 3
  vpc_id                  = aws_vpc.default.id
  cidr_block              = cidrsubnet(var.cidr, 4, count.index)
  map_public_ip_on_launch = true
  availability_zone       = "${data.aws_region.current.name}${element(list("a","b","c"), count.index)}"

  tags = {
    Name = "${var.env}-${element(list("a","b","c"), count.index)}"
    Env  = var.env
  }

  lifecycle {
    ignore_changes = [
      tags,
    ]
  }
}
